@@ -24,8 +24,8 @@
  * ѥ桼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.1.1.1 $
- * $Date: 2010/04/22 01:52:47 $
+ * $Revision: 1.2 $
+ * $Date: 2010/06/10 05:26:46 $
  **********************************************************/
 
 include_once("../../initial");
@@ -114,8 +114,8 @@ function print_form()
 
 <br>
 <input type="hidden" name="sk" value="$sesskey">
-<input type="submit" name="search" value="    ">
-<input type="submit" name="csvdownload" value="CSV">
+<input type="submit" name="search" value="" class="search_btn">
+<input type="submit" name="csvdownload" value="" class="csv_btn">
 EOD;
 
     if($status == STATUS_INPUT) {
